@@ -14,8 +14,9 @@ class StickerSet(base.TelegramObject):
     """
     name: base.String = fields.Field()
     title: base.String = fields.Field()
+    sticker_type: base.String = fields.Field()
     is_animated: base.Boolean = fields.Field()
     is_video: base.Boolean = fields.Field()
-    contains_masks: base.Boolean = fields.Field()
+    contains_masks: base.Boolean = fields.Field()  # Deprecated
     stickers: typing.List[Sticker] = fields.ListField(base=Sticker)
     thumb: PhotoSize = fields.Field(base=PhotoSize)
